@@ -1,4 +1,5 @@
 import click
+from importlib import import_module
 import logging
 
 from .components import components
@@ -9,12 +10,25 @@ log = logging.getLogger()
 
 
 def _call_phase(phase, reverse=False):
-    component_list = reversed(components) if reverse else components
+    component_list = reversed(components) if reverse else [*components]
+    config = Config()
+
+    for extra in config.get("extras", []):
+        module, attr = extra.split(":")
+
+        log.info(f"Adding {extra} to the component tree")
+        component_list.append(getattr(import_module(module), attr))
 
     for component in component_list:
         component.call_phase(phase)
 
 
+def _name_project(project_name):
+    config = Config()
+    config.name = project_name
+    Config.dump(config)
+
+
 @click.group()
 @click.option("--verbose", "-v", is_flag=True)
 def cli(verbose):
@@ -25,8 +39,10 @@ def cli(verbose):
 
 
 @cli.command(help="Creates a new zygoat settings file and exits")
-def init():
-    Config()
+@click.argument("project_name")
+def init(project_name):
+    _name_project(project_name)
+
     log.info(f"Initialized {config_file_name}")
 
 
@@ -35,9 +51,7 @@ def init():
 def new(project_name):
     log.debug(f"Attempting creation of {click.style(project_name, bold=True)}")
 
-    config = Config()
-    config.name = project_name
-    Config.dump(config)
+    _name_project(project_name)
 
     _call_phase(Phases.CREATE)
 
